@@ -33,10 +33,13 @@ def fuzzspecs(specdir = inspecdir):
 
     tfs = []
     specnames = []
+    #print(sfs,".....")
     for spec in sfs:
+        
         if not spec.endswith(".json"):
             continue
         specfname = specdir+"/"+spec
+        #print(specfname)
         testdir   = spec[:-5].lower() + "_tests" # important, convert specs to all lower case 
         tfs.append(testdir)
         specnames.append(spec[:-5].lower())      # convert specs to all lower case 
@@ -53,7 +56,7 @@ def fuzzspecs(specdir = inspecdir):
                                                "",
                                                True)
 
-        shutil.copy("auth.py", "tests")
+        shutil.copy(os.path.join(os.path.dirname(os.path.realpath(__file__)),"auth.py"), "tests")
         if os.path.exists(testdir):
             shutil.rmtree(testdir)
     
